summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp')
-rw-r--r--TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp b/TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp
index ade75a3d827..c2214fe3152 100644
--- a/TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_valuetype/valuetype_ch.cpp
@@ -174,12 +174,13 @@ be_visitor_valuetype_ch::visit_valuetype (be_valuetype *node)
if (is_an_amh_exception_holder)
{
// Generate the constructor and destructor.
*os << be_nl_2
<< node->local_name () << " ( ::CORBA::Exception *ex)" << be_idt_nl
<< ": exception (ex)" << be_uidt_nl
<< "{}" << be_nl_2
- << "virtual ~" << node->local_name () << " (void);";
+ << "virtual ~" << node->local_name () << " (void);" << be_nl
+ << "virtual ::CORBA::ValueBase *_copy_value (void);";
}
*os << be_nl_2
@@ -174,12 +174,13 @@ be_visitor_valuetype_ch::visit_valuetype (be_valuetype *node)
if (is_an_amh_exception_holder)
{
- // Generate the constructor and destructor.
+ // Generate the constructor and destructor and _copy_value.
*os << be_nl_2
<< node->local_name () << " ( ::CORBA::Exception *ex)" << be_idt_nl